@@ -28,7 +28,7 @@ use Scalar::Util qw(blessed);
 
 # NOTE: due to CPAN version checks this cannot currently be changed to a
 # standard version string, i.e. '0.21'
-our $VERSION = '36';
+our $VERSION = '38';
 our $pre_link = undef;
 our $fast_mode = undef;
 our %nagios_setup;
@@ -74,6 +74,9 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
         max_check_attempts            => ['INTEGER',                 280],
         normal_check_interval         => ['INTEGER',                 280],
         retry_check_interval          => ['INTEGER',                 280],
+        check_interval                => ['INTEGER',                 280],
+        retry_interval                => ['INTEGER',                 280],
+        initial_state                 => [[qw(o d u)],               280],
         active_checks_enabled         => ['BINARY',                  280],
         passive_checks_enabled        => ['BINARY',                  280],
         check_period                  => ['Nagios::TimePeriod',      280],
@@ -86,16 +89,22 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
         low_flap_threshold            => ['INTEGER',                 280],
         high_flap_threshold           => ['INTEGER',                 280],
         flap_detection_enabled        => ['BINARY',                  280],
+        flap_detection_options        => [[qw(o d u)],               280],
         process_perf_data             => ['BINARY',                  280],
         retain_status_information     => ['BINARY',                  280],
         retain_nonstatus_information  => ['BINARY',                  280],
         notification_period           => ['Nagios::TimePeriod',      280],
         notification_interval         => ['INTEGER',                 280],
         notification_options          => [[qw(u w c r)],             280],
+        contacts                      => [['Nagios::Contact'],       280],
         contact_groups                => [['Nagios::ContactGroup'],  280],
         notifications_enabled         => ['BINARY',                  280],
         stalking_options              => [[qw(o w u c)],             280],
         failure_prediction_enabled    => ['BINARY',                  16 ],
+        first_notification_delay      => ['INTEGER',                 280],
+        action_url                    => ['STRING',                  280],
+        notes                         => ['STRING',                  280],
+        notes_url                     => ['STRING',                  280],
         name                          => ['service_description',     134],
         comment                       => ['comment',                 280],
         file                          => ['filename',                280]
@@ -120,9 +129,13 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    check_command                 => ['STRING',                  280],
 	    max_check_attempts            => ['INTEGER',                 280],
 	    checks_enabled                => ['BINARY',                  280],
+        initial_state                 => [[qw(o d u)],               280],
+        active_checks_enabled         => ['BINARY',                  280],
+        passive_checks_enabled        => ['BINARY',                  280],
         check_freshness               => ['BINARY',                  280],
         check_interval                => ['INTEGER',                 280],
         retry_interval                => ['INTEGER',                 768],
+        obsess_over_host              => ['BINARY',                  280],
         freshness_threshold           => ['INTEGER',                 280],
 	    event_handler                 => ['STRING',                  280],
 	    event_handler_enabled         => ['BINARY',                  280],
@@ -130,6 +143,7 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    low_flap_threshold            => ['INTEGER',                 280],
 	    high_flap_threshold           => ['INTEGER',                 280],
 	    flap_detection_enabled        => ['BINARY',                  280],
+            flap_detection_options        => [[qw(o d u)],               280],
 	    process_perf_data             => ['BINARY',                  280],
 	    retain_status_information     => ['BINARY',                  280],
 	    retain_nonstatus_information  => ['BINARY',                  280],
@@ -138,8 +152,13 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    notification_options          => [[qw(d u r)],               280],
 	    notifications_enabled         => ['BINARY',                  280],
 	    stalking_options              => [[qw(o d u)],               280],
+            contacts                      => [['Nagios::Contact'],       280],
 	    contact_groups                => [['Nagios::ContactGroup'],  16 ],
         failure_prediction_enabled    => ['BINARY',                  16 ],
+        first_notification_delay      => ['INTEGER',                 280],
+        action_url                    => ['STRING',                  280],
+        notes                         => ['STRING',                  280],
+        notes_url                     => ['STRING',                  280],
 	    name                          => ['host_name',               280],
 	    comment                       => ['comment',                 280],
 	    file                          => ['filename',                280]
@@ -166,6 +185,11 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 		service_notification_commands => [['Nagios::Command'],       280],
 		email                         => ['STRING',                  280],
 		pager                         => ['STRING',                  280],
+        host_notifications_enabled    => ['BINARY',                  280],
+        service_notifications_enabled => ['BINARY',                  280],
+        can_submit_commands           => ['BINARY',                  280],
+        retain_status_information     => ['BINARY',                  280],
+        retain_nonstatus_information  => ['BINARY',                  280],
         address1                      => ['STRING',                  16 ],
         address2                      => ['STRING',                  16 ],
         address3                      => ['STRING',                  16 ],
@@ -225,6 +249,7 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    use                           => ['Nagios::ServiceEscalation',280],
 		host_name                     => ['Nagios::Host',            280],
 		service_description           => ['Nagios::Service',         280],
+        contacts                      => [['Nagios::Contact'],       280],
         contact_groups                => [['Nagios::ContactGroup'],  280],
         first_notification            => ['INTEGER',                 280],
         last_notification             => ['INTEGER',                 280],
@@ -239,10 +264,15 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    use                           => ['Nagios::ServiceDependency',280],
         dependent_host_name           => ['Nagios::Host',            280],
         dependent_service_description => ['Nagios::Service',         280],
+        hostgroup_name                => ['Nagios::HostGroup',       280],
+        dependent_hostgroup_name      => ['Nagios::HostGroup',       280],
 		host_name                     => ['Nagios::Host',            280],
 		service_description           => ['Nagios::Service',         280],
+        inherits_parent               => ['INTEGER',                 280],
 		execution_failure_criteria    => [[qw(o w u c n)],           280],
+		execution_failure_options     => [[qw(o w u c n)],           280],
 		notification_failure_criteria => [[qw(o w u c n)],           280],
+		notification_failure_options  => [[qw(o w u c n)],           280],
         name                          => ['generated',               280],
         comment                       => ['comment',                 280],
         file                          => ['filename',                280]
@@ -251,6 +281,7 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
 	    use                           => ['Nagios::HostEscalation',  280],
 		host_name                     => ['Nagios::Host',            280],
 		hostgroup                     => ['Nagios::HostGroup',       280],
+        contacts                      => [['Nagios::Contact'],       280],
         contact_groups                => [['Nagios::ContactGroup'],  280],
         first_notification            => ['INTEGER',                 280],
         last_notification             => ['INTEGER',                 280],
@@ -262,10 +293,13 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
     HostDependency => {
 	    use                           => ['Nagios::HostDependency',  280],
         dependent_host_name           => ['Nagios::Host',            280],
+        dependent_hostgroup_name      => ['Nagios::HostGroup',       280],
 		host_name                     => ['Nagios::Host',            280],
         inherits_parent               => ['INTEGER',                 16 ],
 		notification_failure_criteria => [[qw(o w u c n)],           280],
+		notification_failure_options  => [[qw(o w u c n)],           280],
 		execution_failure_criteria    => [[qw(o w u c n)],           16 ],
+		execution_failure_options     => [[qw(o w u c n)],           280],
         name                          => ['generated',               280],
         comment                       => ['comment',                 280],
         file                          => ['filename',                280]
@@ -289,6 +323,7 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
         hostgroup                     => [['Nagios::HostGroup'],     18 ],
         notes                         => ['STRING',                  16 ],
         notes_url                     => ['STRING',                  16 ],
+        action_url                    => ['STRING',                  16 ],
         icon_image                    => ['STRING',                  16 ],
         icon_image_alt                => ['STRING',                  16 ],
         vrml_image                    => ['STRING',                  16 ],
@@ -307,6 +342,7 @@ push( @Nagios::Object::EXPORT_OK, '%nagios_setup' );
         service_description           => ['Nagios::Service',         18 ],
         notes                         => ['STRING',                  16 ],
         notes_url                     => ['STRING',                  16 ],
+        action_url                    => ['STRING',                  16 ],
         icon_image                    => ['STRING',                  16 ],
         icon_image_alt                => ['STRING',                  16 ],
         name                          => ['generated',               20 ],
@@ -1056,7 +1092,7 @@ sub set_members {
     }
     # also, before resolution, append to the list rather than replace it
     else {
-        @members = @{ $self->{members} };
+        @members = @{ $self->{members} } if $self->{members};
         foreach my $item ( @_ ) {
             if ( ref($item) eq 'ARRAY' && @$item == 2 ) {
                 push @members, $item;
